@@ -7,9 +7,10 @@ import time
 from scrapy import signals
 from selenium import webdriver
 from selenium_stealth import stealth
-from scrapy.http import HtmlResponse
 from scrapy.exceptions import NotConfigured
 from selenium.webdriver.common.by import By
+from scrapy.http import HtmlResponse, Response
+from selenium.common.exceptions import TimeoutException
 from selenium.webdriver.support.wait import WebDriverWait
 from selenium.webdriver.support import expected_conditions as EC
 
@@ -91,39 +92,43 @@ class SeleniumDownloaderMiddleware:
             )
 
         if "wait_text_to_be_present" in request.meta:
-            if isinstance(request.meta['wait_text_to_be_present'], dict):
-                time.sleep(2)
-                conditionsDict = request.meta['wait_text_to_be_present']
-                for condition in conditionsDict:
-                    print(self.driver.current_url)
-                    if self.driver.current_url.startswith(condition):
-                        WebDriverWait(self.driver, 30).until(
-                            EC.text_to_be_present_in_element(
-                                (By.CSS_SELECTOR, conditionsDict[condition]), '')
-                        )
-            else:
-                WebDriverWait(self.driver, 30).until(
-                    EC.text_to_be_present_in_element(
-                        (By.CSS_SELECTOR, request.meta['wait_text_to_be_present']), '')
-                )
+            try:
+                if isinstance(request.meta['wait_text_to_be_present'], dict):
+                    time.sleep(2)
+                    conditionsDict = request.meta['wait_text_to_be_present']
+                    for condition in conditionsDict:
+                        if self.driver.current_url.startswith(condition):
+                            WebDriverWait(self.driver, 30).until(
+                                EC.text_to_be_present_in_element(
+                                    (By.CSS_SELECTOR, conditionsDict[condition]), '')
+                            )
+                else:
+                    WebDriverWait(self.driver, 30).until(
+                        EC.text_to_be_present_in_element(
+                            (By.CSS_SELECTOR, request.meta['wait_text_to_be_present']), '')
+                    )
+            except TimeoutException:
+                return Response('', status=504)
             del request.meta['wait_text_to_be_present']
 
         if "wait_to_be_clickable" in request.meta:
-            if isinstance(request.meta['wait_to_be_clickable'], dict):
-                time.sleep(2)
-                conditionsDict = request.meta['wait_to_be_clickable']
-                for condition in conditionsDict:
-                    print(self.driver.current_url)
-                    if self.driver.current_url.startswith(condition):
-                        WebDriverWait(self.driver, 30).until(
-                            EC.element_to_be_clickable(
-                                (By.CSS_SELECTOR, conditionsDict[condition]))
-                        )
-            else:
-                WebDriverWait(self.driver, 30).until(
-                    EC.element_to_be_clickable(
-                        (By.CSS_SELECTOR, request.meta['wait_to_be_clickable']))
-                )
+            try:
+                if isinstance(request.meta['wait_to_be_clickable'], dict):
+                    time.sleep(2)
+                    conditionsDict = request.meta['wait_to_be_clickable']
+                    for condition in conditionsDict:
+                        if self.driver.current_url.startswith(condition):
+                            WebDriverWait(self.driver, 30).until(
+                                EC.element_to_be_clickable(
+                                    (By.CSS_SELECTOR, conditionsDict[condition]))
+                            )
+                else:
+                    WebDriverWait(self.driver, 30).until(
+                        EC.element_to_be_clickable(
+                            (By.CSS_SELECTOR, request.meta['wait_to_be_clickable']))
+                    )
+            except TimeoutException:
+                return Response('', status=504)
             del request.meta['wait_to_be_clickable']
 
         body = str.encode(self.driver.page_source)
